@@ -29,32 +29,25 @@
 // as an array.
 //
 
-const fs = require('@npmcli/fs')
+const fs = require('fs/promises')
 const nopt = require('nopt')
+const { resolve } = require('path')
 
 const { definitions, shorthands } = require('../utils/config/index.js')
-const { aliases, cmdList, plumbing } = require('../utils/cmd-list.js')
+const { aliases, commands, plumbing } = require('../utils/cmd-list.js')
 const aliasNames = Object.keys(aliases)
-const fullList = cmdList.concat(aliasNames).filter(c => !plumbing.includes(c))
+const fullList = commands.concat(aliasNames).filter(c => !plumbing.includes(c))
 const configNames = Object.keys(definitions)
 const shorthandNames = Object.keys(shorthands)
 const allConfs = configNames.concat(shorthandNames)
 const { isWindowsShell } = require('../utils/is-windows.js')
-const fileExists = async (file) => {
-  try {
-    const stat = await fs.stat(file)
-    return stat.isFile()
-  } catch {
-    return false
-  }
-}
+const fileExists = (file) => fs.stat(file).then(s => s.isFile()).catch(() => false)
 
 const BaseCommand = require('../base-command.js')
 
 class Completion extends BaseCommand {
   static description = 'Tab Completion for npm'
   static name = 'completion'
-  static ignoreImplicitWorkspace = false
 
   // completion for the completion command
   async completion (opts) {
@@ -62,7 +55,6 @@ class Completion extends BaseCommand {
       return
     }
 
-    const { resolve } = require('path')
     const [bashExists, zshExists] = await Promise.all([
       fileExists(resolve(process.env.HOME, '.bashrc')),
       fileExists(resolve(process.env.HOME, '.zshrc')),
@@ -87,13 +79,11 @@ class Completion extends BaseCommand {
       })
     }
 
-    const { COMP_CWORD, COMP_LINE, COMP_POINT } = process.env
+    const { COMP_CWORD, COMP_LINE, COMP_POINT, COMP_FISH } = process.env
 
     // if the COMP_* isn't in the env, then just dump the script.
-    if (COMP_CWORD === undefined ||
-      COMP_LINE === undefined ||
-      COMP_POINT === undefined) {
-      return dumpScript()
+    if (COMP_CWORD === undefined || COMP_LINE === undefined || COMP_POINT === undefined) {
+      return dumpScript(resolve(this.npm.npmRoot, 'lib', 'utils', 'completion.sh'))
     }
 
     // ok we're actually looking at the envs and outputting the suggestions
@@ -119,6 +109,7 @@ class Completion extends BaseCommand {
     partialWords.push(partialWord)
 
     const opts = {
+      isFish: COMP_FISH === 'true',
       words,
       w,
       word,
@@ -150,9 +141,9 @@ class Completion extends BaseCommand {
     // take a little shortcut and use npm's arg parsing logic.
     // don't have to worry about the last arg being implicitly
     // boolean'ed, since the last block will catch that.
-    const types = Object.entries(definitions).reduce((types, [key, def]) => {
-      types[key] = def.type
-      return types
+    const types = Object.entries(definitions).reduce((acc, [key, def]) => {
+      acc[key] = def.type
+      return acc
     }, {})
     const parsed = opts.conf =
       nopt(types, shorthands, partialWords.slice(0, -1), 0)
@@ -196,10 +187,7 @@ class Completion extends BaseCommand {
   }
 }
 
-const dumpScript = async () => {
-  const { resolve } = require('path')
-  const p = resolve(__dirname, '..', 'utils', 'completion.sh')
-
+const dumpScript = async (p) => {
   const d = (await fs.readFile(p, 'utf8')).replace(/^#!.*?\n/, '')
   await new Promise((res, rej) => {
     let done = false
